==> owncloud-8.1.0p2.tgz: owncloud/apps/files_sharing/l10n/sr@latin.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Deljenje od servera do servera nije omogućeno na ovom serveru.",
    "The mountpoint name contains invalid characters." : "Ime tačke za montiranje sadrži neispravne karaktere.",
    "Invalid or untrusted SSL certificate" : "Nevažeći SSL sertifikat ili SSL sertifikat koji nije od poverenja.",
    "Couldn't add remote share" : "Nemoguće dodavanje udaljenog deljenog direktorijuma",
    "Shared with you" : "Deljeno sa Vama",
    "Shared with others" : "Deljeno sa ostalima",
    "Shared by link" : "Deljeno pomoću prečice",
    "Nothing shared with you yet" : "Još ništa nije deljeno sa Vama",
    "Files and folders others share with you will show up here" : "Fajlovi i direktorijumi koji drugi dele sa Vama će se pojaviti ovde",
    "Nothing shared yet" : "Još ništa nije deljeno",
    "Files and folders you share will show up here" : "Fajlovi i direktorijumi koje vi delite će se pojaviti ovde",
    "No shared links" : "Nema deljenih prečica",
    "Files and folders you share by link will show up here" : "Fajlovi i direktorijumi koje delite putem prečice će se pojaviti ovde",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Da li želite da dodate udaljeni deljeni resurs {name} od {owner}@{remote}?",
    "Remote share" : "Udaljeni deljeni resurs",
    "Remote share password" : "Lozinka za udaljeni deljeni resurs",
    "Cancel" : "Otkaži",
    "Add remote share" : "Dodaj udaljeni deljeni resurs",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nije pronađena ownCloud instalacija (7 ili noviji) na {remote}",
    "Invalid ownCloud url" : "Neispravan ownCloud url",
    "Share" : "Podeli",
    "Shared by" : "Deljeno od strane",
    "A file or folder has been <strong>shared</strong>" : "Fijl ili direktorijum je <strong>podeljen</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Fajl ili direktorijum je deljen sa <strong>drugog servera</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Javni deljeni fajl ili direktorijum je <strong>preuzet</strong>",
    "You received a new remote share from %s" : "Primili ste novi udaljeni deljeni resurs od %s",
    "%1$s accepted remote share %2$s" : "%1$s je prihvatio udaljeni deljeni resurs %2$s",
    "%1$s declined remote share %2$s" : "%1$s je odbio %2$s",
    "%1$s unshared %2$s from you" : "%1$s je prekinuo deljenje %2$s sa Vama",
    "Public shared folder %1$s was downloaded" : "Javni deljeni direktorijum %1$s je preuzet",
    "Public shared file %1$s was downloaded" : "Javni deljeni fajl %1$s je preuzet",
    "You shared %1$s with %2$s" : "Delili ste %1$s sa %2$s",
    "You shared %1$s with group %2$s" : "Delili ste %1$s sa grupom %2$s",
    "%2$s shared %1$s with you" : "%2$s je delio %1$s sa Vama",
    "You shared %1$s via link" : "Delili ste %1$s pomoću prečice",
    "Shares" : "Deljenja",
    "This share is password-protected" : "Ovaj deljeni resurs je zaštićen lozinkom",
    "The password is wrong. Try again." : "Lozinka je netačna. Pokušajte ponovo.",
    "Password" : "Lozinka",
    "No entries found in this folder" : "Nema unosa u ovom direktorijumu",
    "Name" : "Ime",
    "Share time" : "Vreme deljenja",
    "Sorry, this link doesn’t seem to work anymore." : "Žao nam je, ali ova prečica više ne radi.",
    "Reasons might be:" : "Razlozi mogu biti:",
    "the item was removed" : "stavka je uklonjena",
    "the link expired" : "prečica je istekla",
    "sharing is disabled" : "deljenje je onemogućeno",
    "For more info, please ask the person who sent this link." : "Za više informacija, molimo Vas da se obratite osobi koja je poslala prečicu.",
    "Add to your ownCloud" : "Dodaj na svoj ownCloud",
    "Download" : "Preuzmi",
    "Download %s" : "Preuzmi %s",
    "Direct link" : "Direktna prečica",
    "Allow users on this server to send shares to other servers" : "Dozvoli korisnicima na ovom serveru da šalju deljene resurse na druge servere",
    "Allow users on this server to receive shares from other servers" : "Dozvoli korisnicima na ovom serveru da primaju deljene resurse sa drugih servera"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/sr@latin.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Deljenje od servera do servera nije omogućeno na ovom serveru.",
    "The mountpoint name contains invalid characters." : "Ime tačke za montiranje sadrži neispravne karaktere.",
    "Invalid or untrusted SSL certificate" : "Nevažeći SSL sertifikat ili SSL sertifikat koji nije od poverenja.",
    "Couldn't add remote share" : "Nemoguće dodavanje udaljenog deljenog direktorijuma",
    "Shared with you" : "Deljeno sa Vama",
    "Shared with others" : "Deljeno sa ostalima",
    "Shared by link" : "Deljeno pomoću prečice",
    "Uploading..." : "Otpremam…",
    "Nothing shared with you yet" : "Još ništa nije deljeno sa Vama",
    "Files and folders others share with you will show up here" : "Fajlovi i direktorijumi koji drugi dele sa Vama će se pojaviti ovde",
    "Nothing shared yet" : "Još ništa nije deljeno",
    "Files and folders you share will show up here" : "Fajlovi i direktorijumi koje vi delite će se pojaviti ovde",
    "No shared links" : "Nema deljenih prečica",
    "Files and folders you share by link will show up here" : "Fajlovi i direktorijumi koje delite putem prečice će se pojaviti ovde",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Da li želite da dodate udaljeni deljeni resurs {name} od {owner}@{remote}?",
    "Remote share" : "Udaljeni deljeni resurs",
    "Remote share password" : "Lozinka za udaljeni deljeni resurs",
    "Cancel" : "Otkaži",
    "Add remote share" : "Dodaj udaljeni deljeni resurs",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nije pronađena ownCloud instalacija (7 ili noviji) na {remote}",
    "Invalid ownCloud url" : "Neispravan ownCloud url",
    "Share" : "Deljenje",
    "Shared by" : "Deljeno od strane",
    "A file or folder has been <strong>shared</strong>" : "Fijl ili direktorijum je <strong>podeljen</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Fajl ili direktorijum je deljen sa <strong>drugog servera</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Javni deljeni fajl ili direktorijum je <strong>preuzet</strong>",
    "You received a new remote share from %s" : "Primili ste novi udaljeni deljeni resurs od %s",
    "%1$s accepted remote share %2$s" : "%1$s je prihvatio udaljeni deljeni resurs %2$s",
    "%1$s declined remote share %2$s" : "%1$s je odbio %2$s",
    "%1$s unshared %2$s from you" : "%1$s je prekinuo deljenje %2$s sa Vama",
    "Public shared folder %1$s was downloaded" : "Javni deljeni direktorijum %1$s je preuzet",
    "Public shared file %1$s was downloaded" : "Javni deljeni fajl %1$s je preuzet",
    "You shared %1$s with %2$s" : "Delili ste %1$s sa %2$s",
    "You shared %1$s with group %2$s" : "Delili ste %1$s sa grupom %2$s",
    "You shared %1$s via link" : "Delili ste %1$s pomoću prečice",
    "%2$s shared %1$s with you" : "%2$s je delio %1$s sa Vama",
    "Shares" : "Deljenja",
    "This share is password-protected" : "Ovaj deljeni resurs je zaštićen lozinkom",
    "The password is wrong. Try again." : "Lozinka je netačna. Pokušajte ponovo.",
    "Password" : "Lozinka",
    "No entries found in this folder" : "Nema unosa u ovom direktorijumu",
    "Name" : "Ime",
    "Share time" : "Vreme deljenja",
    "Expiration date" : "Datum isteka",
    "Sorry, this link doesn’t seem to work anymore." : "Žao nam je, ali ova prečica više ne radi.",
    "Reasons might be:" : "Razlozi mogu biti:",
    "the item was removed" : "stavka je uklonjena",
    "the link expired" : "prečica je istekla",
    "sharing is disabled" : "deljenje je onemogućeno",
    "For more info, please ask the person who sent this link." : "Za više informacija, molimo Vas da se obratite osobi koja je poslala prečicu.",
    "Add to your ownCloud" : "Dodaj na svoj ownCloud",
    "Download" : "Preuzmi",
    "Download %s" : "Preuzmi %s",
    "Direct link" : "Direktna prečica"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
